@@ -20,19 +20,17 @@ from icepool.die.func import (standard, d, __getattr__, bernoulli, coin,
                               from_cweights, from_sweights, from_rv, align,
                               align_range, apply)
 
-import icepool.die.die
-
 from icepool.die.die import Die
 
-highest = icepool.die.die.Die.highest
-lowest = icepool.die.die.Die.lowest
-max_outcome = icepool.die.die.Die.max_outcome
-min_outcome = icepool.die.die.Die.min_outcome
+highest = Die.highest
+lowest = Die.lowest
+max_outcome = Die.max_outcome
+min_outcome = Die.min_outcome
 
-from icepool.pool.base import BasePool
-from icepool.pool.pool import Pool, standard_pool, DicePool
-from icepool.pool.roll import PoolRoll
+from icepool.pool.base import PoolBase
+from icepool.pool.pool import Pool, standard_pool
 from icepool.pool.eval import EvalPool, WrapFuncEval, SumPool, sum_pool, FindBestSet, FindBestRun
+from icepool.pool.roll import PoolRoll  # Not used externally.
 
 import enum
 
@@ -44,41 +42,10 @@ class SpecialValue(enum.Enum):
 Reroll = SpecialValue.Reroll
 
 __all__ = [
-    'standard',
-    'd',
-    '__getattr__',
-    'bernoulli',
-    'coin',
-    'Die',
-    'from_cweights',
-    'from_sweights',
-    'from_rv',
-    'align',
-    'align_range',
-    'lowest',
-    'highest',
-    'max_outcome',
-    'min_outcome',
-    'apply',
-    'Reroll',
-    'BasePool',
-    'Pool',
-    'standard_pool',
-    'DicePool',
-    # 'PoolRoll',  # Not needed externally due to implicit casts
-    'EvalPool',
-    'WrapFuncEval',
-    'SumPool',
-    'sum_pool',
-    'FindBestSet',
-    'FindBestRun',
-    'd2',
-    'd3',
-    'd4',
-    'd6',
-    'd8',
-    'd10',
-    'd12',
-    'd20',
-    'd100'
+    'standard', 'd', '__getattr__', 'bernoulli', 'coin', 'Die', 'from_cweights',
+    'from_sweights', 'from_rv', 'align', 'align_range', 'lowest', 'highest',
+    'max_outcome', 'min_outcome', 'apply', 'Reroll', 'PoolBase', 'Pool',
+    'standard_pool', 'EvalPool', 'WrapFuncEval', 'SumPool', 'sum_pool',
+    'FindBestSet', 'FindBestRun', 'd2', 'd3', 'd4', 'd6', 'd8', 'd10', 'd12',
+    'd20', 'd100'
 ]
